@@ -104,6 +104,17 @@ class Expression:
     def dice_rolls(self):
         return self.__dice_tosses
 
+    def dice_per_face(self):
+        output = {}
+        faces = self.__dice_tosses[::2]
+        results = self.__dice_tosses[1::2]
+        for face in faces:
+            if face not in output.keys():
+                output[face] = []
+        for i in range(len(results)):
+            output[faces[i]].append(results[i])
+        return output
+
     def __dice_solver(self, string, operand_solver):
         faces = 0
         ad = 0
